@@ -184,27 +184,77 @@ getAllDependencies <- function(pkgdir)
     out
 }
 
+get_deprecated_status_db_url <- function(version) {
+    sprintf(
+        "https://bioconductor.org/checkResults/%s/bioc-LATEST/meat-index.dcf",
+        version
+    )
+}
+
+#' @importFrom BiocFileCache BiocFileCache bfcquery bfcneedsupdate bfcdownload
+#'   bfcrpath
+get_status_file_cache <- function(url) {
+    cache <- tools::R_user_dir("BiocCheck", "cache")
+    bfc <- BiocFileCache(cache, ask = FALSE)
+
+    bquery <- bfcquery(bfc, url, "rname", exact = TRUE)
+    if (identical(nrow(bquery), 1L) && bfcneedsupdate(bfc, bquery[["rid"]]))
+        bfcdownload(x = bfc, rid = bquery[["rid"]], rtype = "web")
+
+    bfcrpath(
+        bfc, rnames = url, exact = TRUE, download = TRUE, rtype = "web"
+    )
+}
+
+.STATUS_FILE_FIELDS <- c(
+    "Package", "Version", "Maintainer", "MaintainerEmail",
+    "PackageStatus", "UnsupportedPlatforms"
+)
+
+.SENTINEL_PACKAGE_STATUS <- matrix(
+    ncol = length(.STATUS_FILE_FIELDS),
+    dimnames = list(NULL, .STATUS_FILE_FIELDS)
+)
+
+.try_read_dcf <- function(file) {
+    pkg_status <- try({
+        read.dcf(
+            file, all = TRUE, fields = .STATUS_FILE_FIELDS
+        )
+    }, silent = TRUE)
+    if (is(pkg_status, "try-error"))
+        .SENTINEL_PACKAGE_STATUS
+    else
+        pkg_status
+}
+
+get_status_from_dcf <- function(status_file) {
+    pkg_status <- .try_read_dcf(status_file)
+    is_deprecated <- pkg_status[, "PackageStatus"] == "Deprecated" &
+        !is.na(pkg_status[, "PackageStatus"])
+    names(is_deprecated) <- pkg_status[, "Package"]
+    is_deprecated
+}
+
+get_deprecated_status <- function(version) {
+    if (version %in% c("release", "devel"))
+        version <- BiocManager:::.version_bioc(version)
+    status_file_url <- get_deprecated_status_db_url(version)
+    status_file <- get_status_file_cache(status_file_url)
+    get_status_from_dcf(status_file)
+}
+
 getAllDeprecatedPkgs <- function()
 {
-    # our best guess at deprecated packages
-    # if write_views wasn't updated to manual add missing package info
-    # a more complete would be to scrap the build report
-    # html = htmlParse("http://bioconductor.org/checkResults/devel/bioc-LATEST/")
-    # depdevel = xpathSApply(html, "//s", xmlValue)
+    ## use the more complete BiocPkgTools::biocBuildReport to identify
+    ## deprecated packages rather than using the VIEWS files
+    deps_release <- get_deprecated_status("release")
+    deps_devel <- get_deprecated_status("devel")
 
-    con <- url("https://bioconductor.org/packages/release/bioc/VIEWS")
-    views_release <- read.dcf(con, all=TRUE)
-    close(con)
-    con <- url("https://bioconductor.org/packages/devel/bioc/VIEWS")
-    views_devel <- read.dcf(con, all=TRUE)
-    close(con)
-    pkgs <- unique(c(
-        views_release[["Package"]][which(views_release[["PackageStatus"]]
-                                         == "Deprecated")],
-        views_devel[["Package"]][which(views_devel[["PackageStatus"]]
-                                       == "Deprecated")]
-        ))
-    pkgs
+    union(
+        names(deps_release[deps_release]),
+        names(deps_devel[deps_devel])
+    )
 }
 
 parseFile <- function(infile, pkgdir) {
@@ -430,10 +480,10 @@ getMaintainerEmail <- function(pkgdir)
     return(email)
 }
 
-docType <- function(rd) {
-    tags <- tools:::RdTags(rd)
-    if (any(tags == "\\docType"))
-        as.character(rd[tags == "\\docType"][[1L]])
+docType <- function(rd, tags) {
+    if (missing(tags))
+        tags <- tools:::RdTags(rd)
+    .tagsExtract(rd, tags, "\\docType")
 }
 
 
@@ -528,9 +578,11 @@ grepPkgDir <- function(pkgdir, greparg, full_path=FALSE){
 
 getVigSources <- function(dir)
 {
-    dir(dir,
+    dir(
+        dir,
         pattern="\\.Rmd$|\\.Rnw$|\\.Rrst$|\\.Rhtml$|\\.Rtex$",
-        ignore.case=TRUE, full.names=TRUE)
+        ignore.case=TRUE, full.names=TRUE
+    )
 }
 
 getRSources <- function(Rdir) {
@@ -711,9 +763,9 @@ getFunctionLengths <- function(df)
 
         }
     } else {
-       res <- list(as.data.frame(list(
+       res <- list(data.frame(
            length = integer(0), startLine = integer(0), endLine = integer(0)
-       )))
+       ))
     }
     res
 }
