@@ -2,10 +2,6 @@ bad_fun <- function(){
 
     update.packages("base")
 
-    for (i in 1:10) {
-        print("test")
-    }
-
     sapply(letters, function(x) x)
 }
 
@@ -47,13 +43,86 @@ bad_install <- function(pkg) {
 
 bad_cat <- function() {
     cat("There is a cat here")
-    print("Using print instead of message")
+    ## except in show methods
     setMethod("show", signature = "character", function(obj) {
         cat("Cat is allowed here")
     })
 }
 
+bad_print <- function() {
+    for (i in 1:10) {
+        print("test")
+    }
+    print("Using print instead of message")
+    lapply(c("A", "B"), print)
+}
+
 bad_assignment <- function() {
     # using = assignment
     value = "there is a equals assignment operator"
 }
+
+## This should not trigger 
+check_install <- function(pkg) {
+    instPkgs <- installed.packages()
+    pkg %in% rownames(instPkgs)
+}
+
+check_inst_pkg <- function(pkg = "getPass") {
+    check_install(pkg = pkg)
+}
+
+## test functions > 50 lines are reported
+really_long_function <- function() {
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  
+  return(TRUE)
+}
\ No newline at end of file
