@@ -320,6 +320,21 @@ test_checkBiocCheckOutputFolder <- function()
     .zeroCounters()
 }
 
+test_checkInstDocFolder <- function() {
+    pkg_folder <- file.path(UNIT_TEST_TEMPDIR, "testPkg")
+    inst_dir <- file.path(pkg_folder, "inst", "doc") 
+    dir.create(inst_dir, recursive = TRUE)
+    BiocCheck:::checkInstDocFolder(pkg_folder, "testpkg")
+    checkEqualsNumeric(.BiocCheck$getNum("error"), 0L)
+    
+    file.create(file.path(inst_dir, "index.html"))
+    BiocCheck:::checkInstDocFolder(pkg_folder, "testpkg")
+    checkEqualsNumeric(.BiocCheck$getNum("error"), 1L)
+    
+    unlink(pkg_folder, recursive = TRUE)
+    .zeroCounters()
+}
+
 test_checkBiocViews <- function()
 {
     if (!dir.exists(UNIT_TEST_TEMPDIR))
@@ -394,6 +409,26 @@ test_checkLicenseForRestrictiveUse <- function() {
     checkEqualsNumeric(1, .BiocCheck$getNum("note"))
 }
 
+test_checkIndivFileSizes <- function() {
+    .zeroCounters()
+    .findLargeFiles_org <- BiocCheck:::.findLargeFiles
+    .findLargeFiles <- function(...) {
+        c("fileA.rda", "fileB.rds")
+    } 
+    assignInNamespace('.findLargeFiles', .findLargeFiles, "BiocCheck")
+    on.exit({
+        assignInNamespace('.findLargeFiles', .findLargeFiles_org, "BiocCheck")
+    })
+    
+    BiocCheck:::checkIndivFileSizes(UNIT_TEST_TEMPDIR)
+    checkEqualsNumeric(.BiocCheck$getNum("warning"), 1)
+    .zeroCounters()
+    
+    BiocCheck:::checkDataFileSizes(UNIT_TEST_TEMPDIR)
+    checkEqualsNumeric(.BiocCheck$getNum("warning"), 1)
+    .zeroCounters()
+}
+
 test_checkBBScompatibility <- function()
 {
     pkgdir <- UNIT_TEST_TEMPDIR
@@ -600,7 +635,7 @@ test_checkBBScompatibility <- function()
 
     cat(
         paste(
-            "citEntry(entry='article', title='test',",
+            "citEntry(entry='', title='test',",
             "author=personList(as.person('Lori Kern')), year=2020,",
             "journal='Loris Best', volume='4', issue='12')"
         ),
@@ -615,6 +650,7 @@ test_checkBBScompatibility <- function()
 
 test_checkUnitTests <- function()
 {
+    .zeroCounters()
     BiocCheck:::checkUnitTests(UNIT_TEST_TEMPDIR)
     checkTrue(.BiocCheck$getNum("note") == 1)
     dir.create(file.path(UNIT_TEST_TEMPDIR, "tests"),recursive=TRUE)
@@ -961,28 +997,6 @@ test_checkDescriptionNamespaceConsistency <- function()
     )
 }
 
-test_checkImportSuggestions <- function()
-{
-    if (requireNamespace("codetoolsBioC", quietly=TRUE)) {
-        suggestions <- BiocCheck:::checkImportSuggestions("RUnit")
-        # sometimes it works and sometimes it doesn't
-        checkTrue(is.character(suggestions))
-
-        pkgpath <- create_test_package()
-        pkgname <- basename(pkgpath)
-        instdir <- BiocCheck:::installAndLoad(pkgpath)
-        require(pkgname, lib.loc = file.path(instdir, "lib"), character.only = TRUE)
-        suggestions <- BiocCheck:::checkImportSuggestions(pkgname)
-        unloadNamespace(pkgname)
-        checkTrue(is.character(suggestions))
-        checkTrue(!length(suggestions))
-
-        suggestions <- BiocCheck:::checkImportSuggestions("FakePackage")
-        checkTrue(is.character(suggestions))
-        checkTrue(inherits(suggestions, "try-error"))
-    }
-}
-
 test_remotesUsage <- function()
 {
     pkg <- system.file("testpackages", "testpkg0", package="BiocCheck")
@@ -1036,6 +1050,17 @@ test_getFunctionLengths2 <- function()
 {
     load(system.file("unitTests", "IRangesParsedCode.rda", package="BiocCheck"))
     BiocCheck:::checkFunctionLengths(IRangesParsedCode, "IRanges")
+    .zeroCounters()
+    
+    ## we should find 1 function that is greater than 50 lines long
+    parsedCode <- BiocCheck:::parseFiles(system.file("testpackages", "testpkg0",
+                                                     package="BiocCheck"))
+    res <- BiocCheck:::checkFunctionLengths(parsedCode, "testpkg0")
+    checkEqualsNumeric(BiocCheck:::.BiocCheck$getNum("note"), 1)
+    checkTrue(grepl(pattern = "There is 1 function greater than 50 lines", 
+                    x = BiocCheck:::.BiocCheck$note$checkFunctionLengths[[1]]),
+              msg = "Checking we report functions > 50 lines long.")
+    .zeroCounters()
 }
 
 test_checkExportsAreDocumented <- function()
@@ -1120,21 +1145,23 @@ test_getPkgType <- function()
 
 test_checkForBiocDevelSubscription <- function()
 {
-    if (nchar(Sys.getenv("BIOC_DEVEL_PASSWORD")))
-    {
+    if (nchar(Sys.getenv("BIOC_DEVEL_PASSWORD"))) {
+
+        if (!dir.exists(UNIT_TEST_TEMPDIR))
+            dir.create(UNIT_TEST_TEMPDIR)
         cat("Maintainer: Joe Blow <foo@bar.com>",
                 file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
         BiocCheck:::checkForBiocDevelSubscription(UNIT_TEST_TEMPDIR)
         checkEqualsNumeric(.BiocCheck$getNum("error"), 1)
         .zeroCounters()
 
-        cat("Maintainer: Dan Tenenbaum <dtenenba@fredhutch.org>",
+        cat("Maintainer: Bioconductor Maintainer <maintainer@bioconductor.org>",
                 file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
         BiocCheck:::checkForBiocDevelSubscription(UNIT_TEST_TEMPDIR)
         checkTrue(stillZero())
         .zeroCounters()
 
-        cat("Maintainer: Dan Tenenbaum <DTENENBA@fredhutch.ORG>",
+        cat("Maintainer: Bioconductor Maintainer <MAINTAINER@bioconductor.ORG>",
                 file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
         BiocCheck:::checkForBiocDevelSubscription(UNIT_TEST_TEMPDIR)
         checkTrue(stillZero())
@@ -1151,16 +1178,15 @@ test_checkForBiocDevelSubscription <- function()
 
         cat(sprintf(paste(
             "Package: %s\nVersion: 0.99.0\nAuthors@R:",
-            "c(person('Dan', \n  'Tenenbaum', email='dtenenba@fredhutch.org',",
+            "c(person('BioC', \n  'Maintainer',",
+            "email='maintainer@bioconductor.org',",
             "role=c('aut', 'cre')))"
         ), UNIT_TEST_PKG), file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
         BiocCheck:::checkForBiocDevelSubscription(UNIT_TEST_TEMPDIR)
         checkTrue(stillZero())
         .zeroCounters()
 
-
     }
-
 }
 
 test_checkForSupportSiteRegistration <- function()
@@ -1301,37 +1327,58 @@ test_doesManPageHaveRunnableExample <- function()
     checkEquals(BiocCheck:::doesManPageHaveRunnableExample(bad), FALSE)
 }
 
+test_checkForValueSection <- function() {
+    man <- system.file(
+        "testpackages", "testpkg0", "man", package = "BiocCheck"
+    )
+    mans <- list.files(man, full.names = TRUE)
+    checkTrue(!BiocCheck:::.valueInManPage(mans[1]))
+    checkTrue(!BiocCheck:::.valueInManPage(mans[2]))
+    checkTrue(BiocCheck:::.valueInManPage(mans[3]))
+    man <- system.file(
+        "testpackages", "testpkg1", "man", package = "BiocCheck"
+    )
+    mans <- list.files(man, full.names = TRUE)
+    checkTrue(!BiocCheck:::.valueInManPage(mans[1]))
+    checkTrue(!BiocCheck:::.valueInManPage(mans[2]))
+}
+
 test_packageAlreadyExists <- function()
 {
     .zeroCounters()
+    nerrors <- 0L
     BiocCheck:::checkIsPackageNameAlreadyInUse("GenomicRanges", "CRAN")
-    checkEqualsNumeric(.BiocCheck$getNum("error"),0)
+    checkEqualsNumeric(.BiocCheck$getNum("error"), nerrors)
     BiocCheck:::checkIsPackageNameAlreadyInUse("devtools", "CRAN")
-    checkEqualsNumeric(.BiocCheck$getNum("error"),1)
+    checkEqualsNumeric(.BiocCheck$getNum("error"), nerrors)
     BiocCheck:::checkIsPackageNameAlreadyInUse("GenomicRanges", "BioCsoft")
-    checkEqualsNumeric(.BiocCheck$getNum("error"),2)
-    BiocCheck:::checkIsPackageNameAlreadyInUse("GO.db", "BioCann")
-    checkEqualsNumeric(.BiocCheck$getNum("error"),3)
+    nerrors <- nerrors + 1L
+    checkEqualsNumeric(.BiocCheck$getNum("error"), nerrors)
+    BiocCheck:::checkIsPackageNameAlreadyInUse("gwascatData", "BioCann")
+    nerrors <- nerrors + 1L
+    checkEqualsNumeric(.BiocCheck$getNum("error"), nerrors)
     BiocCheck:::checkIsPackageNameAlreadyInUse("TENxBrainData", "BioCexp")
-    checkEqualsNumeric(.BiocCheck$getNum("error"),4)
+    nerrors <- nerrors + 1L
+    checkEqualsNumeric(.BiocCheck$getNum("error"), nerrors)
     BiocCheck:::checkIsPackageNameAlreadyInUse("annotation", "BioCworkflows")
-    checkEqualsNumeric(.BiocCheck$getNum("error"),5)
+    nerrors <- nerrors + 1L
+    checkEqualsNumeric(.BiocCheck$getNum("error"), nerrors)
     BiocCheck:::checkIsPackageNameAlreadyInUse("GenomicRanges", "BioCexp")
-    checkEqualsNumeric(.BiocCheck$getNum("error"),5)
+    checkEqualsNumeric(.BiocCheck$getNum("error"), nerrors)
     BiocCheck:::checkIsPackageNameAlreadyInUse("GenomicRanges", "BioCann")
-    checkEqualsNumeric(.BiocCheck$getNum("error"),5)
+    checkEqualsNumeric(.BiocCheck$getNum("error"), nerrors)
     BiocCheck:::checkIsPackageNameAlreadyInUse("GenomicRanges", "BioCworkflows")
-    checkEqualsNumeric(.BiocCheck$getNum("error"),5)
+    checkEqualsNumeric(.BiocCheck$getNum("error"), nerrors)
     BiocCheck:::checkIsPackageNameAlreadyInUse("ImNotFound", "BioCexp")
-    checkEqualsNumeric(.BiocCheck$getNum("error"),5)
+    checkEqualsNumeric(.BiocCheck$getNum("error"), nerrors)
     BiocCheck:::checkIsPackageNameAlreadyInUse("ImNotFound", "BioCann")
-    checkEqualsNumeric(.BiocCheck$getNum("error"),5)
+    checkEqualsNumeric(.BiocCheck$getNum("error"), nerrors)
     BiocCheck:::checkIsPackageNameAlreadyInUse("ImNotFound", "BioCworkflows")
-    checkEqualsNumeric(.BiocCheck$getNum("error"),5)
+    checkEqualsNumeric(.BiocCheck$getNum("error"), nerrors)
     BiocCheck:::checkIsPackageNameAlreadyInUse("ImNotFound", "CRAN")
-    checkEqualsNumeric(.BiocCheck$getNum("error"),5)
+    checkEqualsNumeric(.BiocCheck$getNum("error"), nerrors)
     BiocCheck:::checkIsPackageNameAlreadyInUse("ImNotFound", "BioCsoft")
-    checkEqualsNumeric(.BiocCheck$getNum("error"),5)
+    checkEqualsNumeric(.BiocCheck$getNum("error"), nerrors)
     .zeroCounters()
 }
 
@@ -1348,7 +1395,6 @@ test_BiocCheckReporters <- function()
     checkTrue(
         !dir.exists(hypo_checkdir)
     )
-    .BiocCheck$writeNSsuggests(isOnBBS = TRUE)
     checkTrue(
         !dir.exists(hypo_checkdir)
     )
